
# Catalyzer: 

This is a sample library to enable live visualization with Catalyst in any C/C++ code 

## Compilation

To compile this sample library, you will require the following dependencies:
 - CMake (>= 2.8.8)
 - ParaView with development headers installed (>= 4.3.1).

To install ParaView with the development headers, you can use the following command line:
```
# Configure ParaView with the right options
# -DPARAVIEW_BUILD_QT_GUI=<BOOL> : Enable/Disable paraview GUI (Enabling requires Qt >= 4.7) 
# -DBUILD_TESTING=<BOOL> : Enable/Disable testing (Allows for faster build if disabled and disable external data download) 
cmake <path_to_sources> -DBUILD_TESTING=OFF -DPARAVIEW_BUILD_QT_GUI=ON -DPARAVIEW_ENABLE_CATALYST=ON -DPARAVIEW_ENABLE_PYTHON=ON -DPARAVIEW_INSTALL_DEVELOPMENT_FILES=ON -DPARAVIEW_USE_MPI=ON -DCMAKE_INSTALL_PREFIX=<path_to_install_dir>
# Build ParaView
make -j <njobs>
# Install it
make install
```

## Usage

### Configuration step
To use the Catalyzer library in you CMake-enabled project, 
 - Add the following to your CMakeLists.txt:
```
find_package(Catalyzer REQUIRED)
```
 - Add the Catalyzer installation dir to your CMAKE_PREFIX_PATH variable:
```
export CMAKE_PREFIX_PATH=<path_to_install_dir>/share
```

### Code modification

First you must make sure that your code create its ouput data in the VTK format (e.g. vtkImageData, vtkUnstricturedGrid ...). 
The current code uses data from the vtkDataSet family as an example.

Then modify your code to use the Catalyzer object:
```
# include the library header
#include <catalyzer.h>

...

# Create a instance of the object (only one, for example in your main)
# Use the current worldcomm as argument, if you are using MPI
Catalyzer * catalyzer = new Catalyzer(MPI_WORLD_COMM);

...

# In the code of your Save( ... ) function, instead of writing data to files
# Call the save function of the Catalyzer object
# iStep: being the current time index
# dStep: being the current time step
# data: being the data on the current processor
catalyzer->Save(iStep, dStep, data);

...

# Free memory
delete catalyzer;

```
