/**
 * \file HydroArray.h
 * \brief Define a structure for 2d hydrodynamics simulation run.
 *
 * \date July 8 2013
 * \author P. Kestener
 */

#ifndef HYDRO_ARRAY_H_
#define HYDRO_ARRAY_H_

#include <stdlib.h> // for malloc

#include "../real_type.h"

/**************************************************/
/**************************************************/
/**************************************************/

/**
 * Hydro2d array. Storage is column major order.
 */
struct HydroArray2d {
  int isize, jsize;    /*!< sizes in element in each direction */
  int nVar;            /*!< number of fields (rho, E, mx, my, ...) */
  real_t *data;        /*!< pointer to data array */
};
typedef struct HydroArray2d HydroArray2d;

/* HydroArray2d routines. */
HydroArray2d * HydroArray2d_new  (int isize, int jsize, int nVar);
void      HydroArray2d_free   (      HydroArray2d *array);
void      HydroArray2d_print  (const HydroArray2d* array);
real_t    HydroArray2d_get_idx(const HydroArray2d* array, int idx);
void      HydroArray2d_set_idx(      HydroArray2d* array, int idx, real_t value);
real_t    HydroArray2d_get    (const HydroArray2d* array, int i, int j, int ivar);
void      HydroArray2d_set    (      HydroArray2d* array, int i, int j, int ivar, real_t value);
void      HydroArray2d_incr   (      HydroArray2d* array, int i, int j, int ivar, real_t value);


#endif // HYDRO_ARRAY_H_
