/**
 *
 */
#ifndef HYDRO_RUN_H_
#define HYDRO_RUN_H_

#include "array/HydroArray.h"
#include "hydroParams.h"

/**
 * Riemann solver. Define function pointer type.
 * 
 */
typedef void (*riemann_solver_t) (const real_t qleft[nbVar], 
				  const real_t qright[nbVar], 
				  real_t qgdnv[nbVar], 
				  real_t flux[nbVar]);

/**
 * Main hydrodynamics data structure.
 */
struct HydroWorkspace {
  
  HydroArray2d* U;    /*!< hydrodynamics conservative variables arrays */
  HydroArray2d* U2;   /*!< hydrodynamics conservative variables arrays */
  HydroArray2d* Q;    /*!< hydrodynamics primitive    variables array  */
  HydroArray2d* Qm_x; /*!< hydrodynamics Riemann states array */
  HydroArray2d* Qm_y; /*!< hydrodynamics Riemann states array */
  HydroArray2d* Qp_x; /*!< hydrodynamics Riemann states array */
  HydroArray2d* Qp_y; /*!< hydrodynamics Riemann states array */

  riemann_solver_t riemann_solver_fn; /*!< riemann solver function pointer */

};
typedef struct HydroWorkspace HydroWorkspace;

void initHydroRun(HydroWorkspace* workspace);

void cleanupHydroRun(HydroWorkspace* workspace);

real_t compute_dt(HydroWorkspace* workspace, int useU);

void godunov_unsplit(HydroWorkspace* workspace, int nStep, real_t dt);

void godunov_unsplit_cpu(HydroWorkspace* workspace,
			 HydroArray2d* data_in, 
			 HydroArray2d* data_out, 
			 real_t dt, 
			 int nStep);

void convertToPrimitives(HydroArray2d *U, HydroArray2d *Q);

void computeTrace(HydroWorkspace* workspace, HydroArray2d *U, real_t dt);

void computeFluxesAndUpdate(HydroWorkspace* workspace, 
			    HydroArray2d *U, 
			    real_t dt);

void init_implode(HydroArray2d* U);
void init_blast(HydroArray2d* U);

void write_pvtk_wrapper(int iStep);
void saveVTK(HydroArray2d* U, int iStep);

void make_boundaries_external(HydroArray2d *U);
void make_boundaries_internal(HydroArray2d *U);

#endif // HYDRO_RUN_H_
